/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "WebKitCSSTransformValue.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomCSSValueList.h"
#include "gdom/GdomWebKitCSSTransformValue.h"
#include "gdom/PrivateGdomCSSValueList.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomWebKitCSSTransformValue.h"
#include "gdom/PrivateIntGdomWebKitCSSTransformValue.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMWebKitCSSTransformValue::GDOMWebKitCSSTransformValue(PassRefPtr<WebCore::WebKitCSSTransformValue> impl)
    : GDOMCSSValueList(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "WebKitCSSTransformValue.h"
#include <gdom/GdomWebKitCSSTransformValue.h>
#include <gdom/PrivateGdomWebKitCSSTransformValue.h>
#include <gdom/PrivateIntGdomWebKitCSSTransformValue.h>
#include <gdom/GdomWebKitCSSTransformValueprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomWebKitCSSTransformValue, gdom_web_kit_css_transform_value, GDOM_TYPE_CSS_VALUE_LIST);

/*
struct _GdomWebKitCSSTransformValuePrivate {
    class WebCore::WebKitCSSTransformValue *item;
};

#define GDOM_WEB_KIT_CSS_TRANSFORM_VALUE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_WEB_KIT_CSS_TRANSFORM_VALUE, GdomWebKitCSSTransformValuePrivate))
*/
G_END_DECLS
WebCore::WebKitCSSTransformValue *
gdom_web_kit_css_transform_value_get_private(GdomWebKitCSSTransformValue *request)
{
    GDOMWebKitCSSTransformValue *res;
    res = static_cast<GDOMWebKitCSSTransformValue*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::WebKitCSSTransformValue*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_OPERATION_TYPE,
};


static void gdom_web_kit_css_transform_value_finalize(GObject* object)
{
    /*GdomWebKitCSSTransformValue* request = GDOM_WEB_KIT_CSS_TRANSFORM_VALUE(object);*/
    /*GdomWebKitCSSTransformValuePrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_CSS_VALUE_LIST));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_web_kit_css_transform_value_parent_class)->finalize(object);
}

static void gdom_web_kit_css_transform_value__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomWebKitCSSTransformValue *self = GDOM_WEB_KIT_CSS_TRANSFORM_VALUE(object);
    WebCore::WebKitCSSTransformValue * gself = (gdom_web_kit_css_transform_value_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_web_kit_css_transform_value__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomWebKitCSSTransformValue *self = GDOM_WEB_KIT_CSS_TRANSFORM_VALUE(object);
    WebCore::WebKitCSSTransformValue * gself = (gdom_web_kit_css_transform_value_get_private(self));
    switch (prop_id) {
    case PROP_OPERATION_TYPE:
    {
         g_value_set_uint (value, gself->operationType());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_web_kit_css_transform_value_class_init(GdomWebKitCSSTransformValueClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_web_kit_css_transform_value_finalize;
    g_klass->set_property = gdom_web_kit_css_transform_value__set_property_fn;
    g_klass->get_property = gdom_web_kit_css_transform_value__get_property_fn;

    g_object_class_install_property (g_klass, PROP_OPERATION_TYPE,
            g_param_spec_uint ("operation_type", /* name */
                "web_kit_css_transform_value_operation_type", /* short description */
                "read-only  gushort WebKitCSSTransformValue.operation_type", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXUINT16, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomWebKitCSSTransformValuePrivate));*/
}

static void gdom_web_kit_css_transform_value_init(GdomWebKitCSSTransformValue* request)
{
    /*GdomWebKitCSSTransformValuePrivate* priv = GDOM_WEB_KIT_CSS_TRANSFORM_VALUE_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

